function fvvars

% Competition simulation parameter declarations
% Note that 'per 100-m coastline' is implicit in
% these declarations.

global duration front advec diffus habitat; 
global size1 birth1 adeath1 ldeath1 settle1;
global size2 birth2 adeath2 ldeath2 settle2;
global length time area;
global delx delt xmax tmax;
global xf u k A a1 m1 mu1 nu1 c1 a2 m2 mu2 nu2 c2;

% Parameter values: lengths in meters, time in hours

% Physical parameters

duration = 30000; % simulation duration
front = 30000;    % distance from coast to front
advec = 100;      % offshore advection rate
diffus = 36000;   % eddy diffusivity
habitat = 100;    % benthic habitat area per 100-m coastline

% Biological parameters

size1 = .0001;    % basal area of adult
size2 = .00005;   
birth1 = 0.024;   % larval production rate
birth2 = 0.15;
adeath1 = 0.0002; % adult mortality rate
adeath2 = 0.0002;
ldeath1 = 0.002;  % larval mortality rate
ldeath2 = 0.002;
settle1 = 0.02;   % settlement coefficient: net units are 
                  % per time, but distance offshore is in the
                  % numerator, and height of benthic habitat is
                  % in the denominator.
settle2 = 0.02;

% Characteristics

time = 100; 
length = 100; % in the offshore direction
area = 100; % area of benthic habitat


% Numerical parameters

delx = 1; % numerical step size in the offshore direction
delt = 1; % numerical step size in time 
xmax = round(front/(length*delx)); % number of steps to the 
					     % upwelling front
tmax = round(duration/(time*delt)); % number of time steps 
					      % in the simulation

% Nondimensionalized physical parameters

xf = front/length;
u = advec*time/length;
k = diffus*time/(length*length);
A = habitat/area; 

% Nondimensionalized biological parameters

a1 = size1/area;
m1 = birth1*time;
mu1 = adeath1*time;
nu1 = ldeath1*time;
c1 = settle1*time*area/length;
a2 = size2/area;
m2 = birth2*time;
mu2 = adeath2*time;
nu2 = ldeath2*time;
c2 = settle2*time*area/length;