function fvvarspp

% Predator-prey simulation parameter declarations
% Note that 'per 100-m coastline' is implicit in
% these declarations.

global duration front advec diffus habitat encount; 
global size1 birth1 adeath1 ldeath1 settle1;
global birth2 adeath2 ldeath2 settle2;
global length time area;
global delx delt xmax tmax;
global xf u k A e a1 m1 mu1 nu1 c1 m2 mu2 nu2 c2;
global N1o L1o N2o L2o;


% Parameter values: lengths in meters, time in hours

% Physical parameters

duration = 200000; % simulation duration
front = 30000;     % distance from coast to front
advec = 100; 	 % offshore advection rate
diffus = 36000; 	 % eddy diffusivity
habitat = 100;     % benthic habitat area per 100-m coastline
encount = 0.00001; % proportion of habitat in a unit length
                   % of coastline searched per unit time

% Biological parameters
                
size1 = .0001; 	% basal area of adult
adeath1 = 0.0005; % adult mortality rate
adeath2 = 0.00001;
ldeath1 = 0.002;  % larval mortality rate
ldeath2 = 0.002;
settle1 = 0.02;   % settlement coefficient
settle2 = 0.0001;
birth1 = 0.05;    % larval production rate
birth2 = 0.06;    % number predators produced per prey eaten


% Characteristics

time = 100; 
length = 100; % in the offshore direction
area = 100; % area of benthic habitat

% Numerical parameters

delx = 0.5; % numerical step size in the offshore direction
delt = 1;   % numerical step size in time
xmax = round(front/(length*delx)); % number of steps to the
					     % upwelling front
tmax = round(duration/(time*delt)); % number of time steps
						% in the simulation

% Nondimensionalized physical parameters

xf = front/length;
u = advec*time/length;
k = diffus*time/(length*length);
A = habitat/area;

% Nondimensionalized biological parameters

e = encount*time;
a1 = size1/area;
m1 = birth1*time;
mu1 = adeath1*time;
nu1 = ldeath1*time;
c1 = settle1*time*area/length;
m2 = birth2;
mu2 = adeath2*time;
nu2 = ldeath2*time;
c2 = settle2*time*area/length;